<!-- 文档编辑 -->
<template>
  <div class="app-container">
    <el-form ref="agreementForm" label-position="left" :model="mData" label-width="150px" :rules="rules">
      <el-form-item v-if="haveTitle" label="标题：">
        <!-- <el-input v-model="mData.title" placeholder="请输入标题" class="com-edit-input" /> -->
        <div class="com-edit-input">{{ titleOptions[type-1] }}</div>
      </el-form-item>
      <el-form-item v-if="haveContent" label="文档详情：" prop="content">
        <WangEnduit :catchdata="catchData" :content="mData.content" :rangenum="rangenum" />
      </el-form-item>
    </el-form>
    <div class="com-edit-bottom-btns flex flex-align-center">
      <el-button size="small" @click="jumpBack">取消</el-button>
      <el-button type="primary" size="small" @click="submit">保存</el-button>
    </div>
  </div>
</template>

<script>
import mixin_upload from '@/mixins/upload.js' // 通用上传图片预览
import WangEnduit from '@/components/WangEnduit' // 富文本
export default {
  name: 'Agreement',
  components: { WangEnduit },
  mixins: [mixin_upload],
  data() {
    return {
      type: this.$route.meta.type, // 协议类型
      // 富文本
      rangenum: null,

      titleOptions: ['报价公告及违规规则', '竞价平台中标原则及公告', '操作流程说明'],

      mData: {
        title: '', // 标题
        content: '' // 富文本
      },

      // 表单校验
      rules: {
        title: [
          { required: true, message: '标题不能为空', trigger: 'change' }
        ],
        content: [
          { required: true, message: '文档详情不能为空' }
        ],
        uploadImgs: [
          { required: true, message: '请选择图片', trigger: 'change' }
        ]
      }
    }
  },
  computed: {
    haveTitle() {
      return true
    },
    haveContent() {
      return true
    }
  },
  watch: {
    $route() {
      this.init()
    }
  },
  mounted() {
    this.init()
  },
  methods: {
    init() {
      this.getAgreementData()
    },

    // 获取文章详情
    getAgreementData() {
      this.postFN({
        url: 'admin/sysTextExplain/detail',
        params: { type: this.type },
        udData: {},
        mockData: {
          code: 100, msg: '',
          data: {
            id: 'xxx',
            content: '<p>文本</p>'
          }
        }
      }, (inf) => {
        if (inf) this.$set(this.mData, 'content', inf.content || '')
        // 清空富文本
        this.rangenum = null
      })
    },

    // 富文本相关
    // 富文本编辑器的内容赋值
    catchData(content) {
      if (content === '<p><br></p>') content = ''
      try {
        const currentRange = window.getSelection().getRangeAt(0)
        this.rangenum = currentRange
      } catch (e) {
        //
      }
      this.mData.content = content
      this.$refs.agreementForm.validateField('content')
    },
    // 富文本相关

    jumpBack() {
      this.$router.go(-1)
    },

    // 表单验证
    submit() {
      this.$refs['agreementForm'].validate(valid => {
        if (valid) {
          this.submitReq()
        }
      })
    },
    // 提交
    submitReq() {
      var { mData } = this
      var params = {
        type: this.type,
        // title: mData.title,
        content: mData.content
      }

      if (!this.haveContent) {
        params.content = '无'
      }
      // if (!this.haveTitle) {
      //   params.title = '无'
      // }

      this.postFN({
        url: 'admin/sysTextExplain/edit',
        params: params,
        mockData: {
          code: 100,
          msg: '',
          data: {}
        }
      }, () => {
        this.$messageSuc('保存成功')
      })
    }
  }
}
</script>

<style lang="less">

</style>
